# ANTS-Hub - Copyright (C) Entr'ouvert

import uuid

from django.core.exceptions import ValidationError
from django.db import models


def generate_apikey():
    return uuid.uuid4().hex


class Raccordement(models.Model):
    name: str = models.CharField(verbose_name='Nom', max_length=256, unique=True)
    apikey = models.CharField(
        verbose_name='API key',
        max_length=64,
        default=generate_apikey,
        unique=True,
        help_text='Écrire "NEW" pour en générer une nouvelle.',
    )
    notes = models.TextField(verbose_name="Notes", blank=True)

    def __str__(self):
        return self.name

    def clean(self):
        if self.apikey.strip() == 'NEW':
            self.apikey = generate_apikey()
        self.apikey = self.apikey.strip()
        if len(self.apikey) < 32:
            raise ValidationError('API key doit faire au moins 32 caractères')

    class Meta:
        verbose_name = 'Raccordement'
        verbose_name_plural = 'Raccordements'
        ordering = ('name',)
        db_table = 'ants_hub_raccordement'
